// Listen for changes in chrome.storage.sync
chrome.storage.onChanged.addListener((changes, namespace) => {
  if (namespace === 'sync' && changes.jbitsStylerSettings) {
    console.log('JBITS Styler: Settings changed. Notifying content scripts.');

    // Find tabs running on the target URL
    chrome.tabs.query({ url: "https://www.jbits.courts.state.co.us/*" }, (tabs) => {
      if (chrome.runtime.lastError) {
          console.error("Error querying tabs:", chrome.runtime.lastError);
          return;
      }
      tabs.forEach(tab => {
        // Send a message to the content script in each matching tab
        chrome.tabs.sendMessage(tab.id, { type: 'UPDATE_STYLES' }, (response) => {
            if (chrome.runtime.lastError) {
                console.log(`JBITS Styler: Could not send message to tab ${tab.id}. Maybe it's closed or navigating. Error: ${chrome.runtime.lastError.message}`);
            } else {
                console.log(`JBITS Styler: Message sent to tab ${tab.id}, response:`, response?.status);
            }
        });
      });
    });
  }
});

// Optional: Make the extension icon open the options page
chrome.action.onClicked.addListener((tab) => {
  chrome.runtime.openOptionsPage();
});